==> rn-hidoop-ui-lib-0.1.11.tgz: package/src/Components/Molecules/Picker/PickerList.js <==
/**
 * Sample of calling this picker
 * function showModalPrint() {
    pickerIconRef?.current?.showPicker(
              {
                title: 'Filter Kategori',
                type: 'basic',
                options: [
                  { title: 'Rumah & Otomotif', image: Icons.automotiveIco },
                ],
              },
              (item) => {
                console.log('return value', item);
              }
            )
  }
 */

import React, { forwardRef, useImperativeHandle, useState } from 'react';
import { StyleSheet, TouchableOpacity, View } from 'react-native';
import Modal from 'react-native-modal';
import { colors, width } from '../../../constant/theme';
import { Icon, Text } from '../../Atoms';
import PickerIcon from './PickerIcon';
import RadioPicker from './RadioPicker';

const PickerList = forwardRef(({ ...props }, ref) => {
  let Body = null;

  const [pickerData, setPickerData] = useState({
    isVisible: false,
    title: '',
  });

  useImperativeHandle(ref, () => ({
    showPicker: (basedata, onSelect) => _showPicker(basedata, onSelect),
    closePicker: () => _closePicker(),
  }));

  if (pickerData?.type === 'radio') {
    Body = (
      <RadioPicker
        data={pickerData?.options}
        onSelect={(item) => {
          pickerData?.onSelect(item);
          _closePicker();
        }}
        selectedId={pickerData?.selectedId?.toString()}
      />
    );
  } else if (pickerData?.type === 'basic') {
    Body = (
      <PickerIcon
        data={pickerData?.options}
        onSelect={(item) => {
          pickerData?.onSelect(item);
          _closePicker();
        }}
      />
    );
  } else {
    Body = null;
  }

  return (
    <Modal
      onBackdropPress={_closePicker}
      onBackButtonPress={_closePicker}
      animationIn="slideInUp"
      isVisible={pickerData?.isVisible}
      swipeDirection={['down']}
      style={styles.wrapper}
      propagateSwipe
      useNativeDriver
      {...props}
    >
      <View style={styles.container}>
        <View style={styles.contentHeader}>
          <Text variant="bold" size="large" text={pickerData?.title} />
          <TouchableOpacity onPress={_closePicker}>
            <Icon name="close-line" color={colors.grey.grey8} size={20} />
          </TouchableOpacity>
        </View>
        {Body}
      </View>
    </Modal>
  );

  function _showPicker(data, cb) {
    setPickerData({
      ...data,
      isVisible: true,
      onSelect: cb,
    });
  }

  function _closePicker() {
    setPickerData({
      isVisible: false,
      title: null,
    });
  }
});

const styles = StyleSheet.create({
  wrapper: {
    justifyContent: 'flex-end',
    margin: 0,
  },
  container: {
    padding: width * 0.05,
    backgroundColor: 'white',
    borderRadius: 4,
    borderColor: 'rgba(0, 0, 0, 0.1)',
    borderTopLeftRadius: 20,
    borderTopRightRadius: 20,
  },
  contentHeader: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    width: '100%',
  },
});

export default PickerList;

==> rn-hidoop-ui-lib-0.1.13.tgz: package/src/Components/Molecules/Picker/PickerList.js <==
/**
 * Sample of calling this picker
 * function showModalPrint() {
    pickerIconRef?.current?.showPicker(
              {
                title: 'Filter Kategori',
                type: 'basic',
                options: [
                  { title: 'Rumah & Otomotif', image: Icons.automotiveIco },
                ],
              },
              (item) => {
                console.log('return value', item);
              }
            )
  }
 */

import React, { forwardRef, useImperativeHandle, useState } from 'react';
import { StyleSheet, TouchableOpacity, View } from 'react-native';
import Modal from 'react-native-modal';
import { colors, width } from '../../../constant/theme';
import { Icon, Text } from '../../Atoms';
import PickerIcon from './PickerIcon';
import PickerIconGroup from './PickerIconGroup';
import RadioPicker from './RadioPicker';

const PickerList = forwardRef(({ disableBackdrop, ...props }, ref) => {
  let Body = null;

  const [pickerData, setPickerData] = useState({
    isVisible: false,
    title: '',
  });

  useImperativeHandle(ref, () => ({
    showPicker: (basedata, onSelect) => _showPicker(basedata, onSelect),
    closePicker: () => _closePicker(),
  }));

  if (pickerData?.type === 'radio') {
    Body = (
      <RadioPicker
        data={pickerData?.options}
        onSelect={(item) => {
          pickerData?.onSelect(item);
          _closePicker();
        }}
        selectedId={pickerData?.selectedId?.toString()}
      />
    );
  } else if (pickerData?.type === 'basic') {
    Body = (
      <PickerIcon
        data={pickerData?.options}
        onSelect={(item) => {
          pickerData?.onSelect(item);
          _closePicker();
        }}
      />
    );
  } else if (pickerData?.type === 'basicGroup') {
    Body = (
      <PickerIconGroup
        data={pickerData?.options}
        onSelect={(item) => {
          pickerData?.onSelect(item);
          _closePicker();
        }}
      />
    );
  } else {
    Body = null;
  }

  return (
    <Modal
      onBackdropPress={disableBackdrop ? null : _closePicker}
      onBackButtonPress={disableBackdrop ? null : _closePicker}
      animationIn="slideInUp"
      isVisible={pickerData?.isVisible}
      swipeDirection={['down']}
      style={styles.wrapper}
      propagateSwipe
      useNativeDriver
      {...props}
    >
      <View style={styles.container}>
        <View style={styles.contentHeader}>
          <Text variant="bold" size="large" text={pickerData?.title} />
          <TouchableOpacity onPress={_closePicker}>
            <Icon name="close-line" color={colors.grey.grey8} size={20} />
          </TouchableOpacity>
        </View>
        {Body}
      </View>
    </Modal>
  );

  function _showPicker(data, cb) {
    setPickerData({
      ...data,
      isVisible: true,
      onSelect: cb,
    });
  }

  function _closePicker() {
    setPickerData({
      isVisible: false,
      title: null,
    });
  }
});

const styles = StyleSheet.create({
  wrapper: {
    justifyContent: 'flex-end',
    margin: 0,
  },
  container: {
    padding: width * 0.05,
    backgroundColor: 'white',
    borderRadius: 4,
    borderColor: 'rgba(0, 0, 0, 0.1)',
    borderTopLeftRadius: 20,
    borderTopRightRadius: 20,
  },
  contentHeader: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    width: '100%',
  },
});

export default PickerList;
